==> ion-java-1.11.4-sources.jar: com/amazon/ion/impl/lite/IonStringLite.java <==
/*
 * Copyright 2007-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazon.ion.impl.lite;

import com.amazon.ion.IonString;
import com.amazon.ion.IonType;
import com.amazon.ion.IonWriter;
import com.amazon.ion.ValueVisitor;
import java.io.IOException;


final class IonStringLite
    extends IonTextLite
    implements IonString
{
    private static final int HASH_SIGNATURE =
        IonType.STRING.toString().hashCode();

    /**
     * Constructs a <code>null.string</code> value.
     */
    IonStringLite(ContainerlessContext context, boolean isNull)
    {
        super(context, isNull);
    }

    IonStringLite(IonStringLite existing, IonContext context)
    {
        super(existing, context);
        // no need to set values as these are set at the parent IonTextLite
    }

    @Override
    IonValueLite shallowClone(IonContext parentContext)
    {
        return new IonStringLite(this, parentContext);
    }

    @Override
    public IonStringLite clone()
    {
        return (IonStringLite) shallowClone(ContainerlessContext.wrap(getSystem()));
    }

    @Override
    int hashSignature() {
        return HASH_SIGNATURE;
    }

    @Override
    int scalarHashCode()
    {
        int result = HASH_SIGNATURE;
        result ^= _text_value.hashCode();

        return hashTypeAnnotations(result);
    }

    @Override
    public IonType getType()
    {
        return IonType.STRING;
    }

    @Override
    final void writeBodyTo(IonWriter writer, SymbolTableProvider symbolTableProvider)
        throws IOException
    {
        writer.writeString(_text_value);
    }

    @Override
    public void accept(ValueVisitor visitor) throws Exception
    {
        visitor.visit(this);
    }

}

==> ion-java-1.11.10-sources.jar: com/amazon/ion/impl/lite/IonStringLite.java <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
package com.amazon.ion.impl.lite;

import com.amazon.ion.IonString;
import com.amazon.ion.IonType;
import com.amazon.ion.IonWriter;
import com.amazon.ion.ValueVisitor;
import java.io.IOException;


final class IonStringLite
    extends IonTextLite
    implements IonString
{
    private static final int HASH_SIGNATURE =
        IonType.STRING.toString().hashCode();

    /**
     * Constructs a <code>null.string</code> value.
     */
    IonStringLite(ContainerlessContext context, boolean isNull)
    {
        super(context, isNull);
    }

    IonStringLite(IonStringLite existing, IonContext context)
    {
        super(existing, context);
        // no need to set values as these are set at the parent IonTextLite
    }

    @Override
    IonValueLite shallowClone(IonContext parentContext)
    {
        return new IonStringLite(this, parentContext);
    }

    @Override
    public IonStringLite clone()
    {
        return (IonStringLite) shallowClone(ContainerlessContext.wrap(getSystem()));
    }

    @Override
    int hashSignature() {
        return HASH_SIGNATURE;
    }

    @Override
    int scalarHashCode()
    {
        int result = HASH_SIGNATURE;
        result ^= _text_value.hashCode();

        return hashTypeAnnotations(result);
    }

    @Override
    public IonType getTypeSlow()
    {
        return IonType.STRING;
    }

    @Override
    final void writeBodyTo(IonWriter writer, SymbolTableProvider symbolTableProvider)
        throws IOException
    {
        writer.writeString(_text_value);
    }

    @Override
    public void accept(ValueVisitor visitor) throws Exception
    {
        visitor.visit(this);
    }

}
